@@ -14,13 +14,13 @@ POE::Declare::Meta::Timeout - A named timeout with generated support methods
       $_[SELF]->{handle}->put('something');
   }
   
-  # Recieved a response
+  # Received a response
   sub response : Event {
       if ( $_[ARG0] eq 'keepalive' ) {
           $_[SELF]->request_timeout_restart;
           return;
       }
-
+  
       $_[SELF]->request_timeout_stop;
       $_[SELF]->{parent}->post('child_response', $_[ARG0]);
   }
@@ -46,7 +46,7 @@ use POE::Declare::Meta::Event ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '0.50';
+	$VERSION = '0.51';
 	@ISA     = 'POE::Declare::Meta::Event';
 }
 
@@ -63,7 +63,7 @@ use Class::XSAccessor {
 #####################################################################
 # Main Methods
 
-sub _compile {
+sub as_perl {
 	my $name  = $_[0]->{name};
 	my $delay = $_[0]->{delay};
 	return <<"END_PERL";
@@ -104,7 +104,7 @@ L<POE>, L<POE::Declare>
 
 =head1 COPYRIGHT
 
-Copyright 2006 - 2010 Adam Kennedy.
+Copyright 2006 - 2011 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
